@@ -1,8 +1,8 @@
 use strict;
 use warnings;
 package Alien::SeqAlignment::edlib;
-$Alien::SeqAlignment::edlib::VERSION = '0.06';
-# VERSION  '0.06';
+$Alien::SeqAlignment::edlib::VERSION = '0.07';
+$Alien::SeqAlignment::edlib = '0.07';
 
 use parent qw( Alien::Base );
 
@@ -45,38 +45,49 @@ The build provides the static and shared libraries, but also the CLI aligner
 
 Returns the command name for running the CLI version of the edlib aligner
 Since the command line tool is not built under Windows by the edlib project
-make files, this method will return undef under Windows. Note that the method
-can only be called in scalar context
+make files, this method will return undef under Windows. 
 
 =cut
 
 sub exe {
     my ($class) = @_;
-    die "Cannot call Alien::SeqAlignment::edlib->exe in list context"
-      if wantarray;
     $^O ne 'MSWin32' ? $class->runtime_prop->{command} : undef;
 }
 
-=head1 HELPERS
+=head1 USAGE
 
-%{edlib_aligner}
+ use v5.38;
+ use Alien::SeqAlignment::edlib;
+ use Env qw( @PATH );
 
-=head2 edlib_aligner
+ unshift @PATH, Alien::SeqAlignment::edlib->bin_dir;
+ my $string1 =      "ACGACG";
+ my $string2 = "CCCCCACGTCG";
 
-Returns the CLI command for the edlib aligner
+ # save sequences
+ open my $fh, '>', 'seq1.fasta';
+ say $fh ">Seq1\n$string1";
+ close $fh;
+ open my $fh, '>', 'seq2.fasta';
+ say $fh ">Seq2\n$string2";
+ close $fh;
 
-=cut
+ system Alien::SeqAlignment::edlib->exe, '-m', 'HW','-n','0', '-k','-1','-p','-f' ,'NICE','seq1.fasta', 'seq2.fasta';
 
-sub alien_helper {
-  my($class) = @_;
-  return {
-    edlib_aligner => sub {
-      # return the CLI command for the edlib aligner
-      Alien::SeqAligment::edlib->exe;
-    }
-  },
-}
+ # output
 
+Using HW alignment mode.
+Reading queries...
+Read 1 queries, 6 residues total.
+Reading target fasta file...
+Read target, 11 residues.
+
+Comparing queries to target...
+
+Query #0 (6 residues): score = 1
+T: ACGTCG (5 - 10)
+   ||| ||
+Q: ACGACG (0 - 5)
 
 =head1 SEE ALSO
 
